/**
 * SVG Core Definitions
 */

import {IconDefinition, IconLookup, IconName, IconPrefix, IconPathData, IconPack } from '@fortawesome/fontawesome-common-types';
export {IconDefinition, IconLookup, IconName, IconPrefix, IconPathData, IconPack } from '@fortawesome/fontawesome-common-types';
export const prefix: IconPrefix;

export const dom: DOM;
export const library: Library;
export const parse: { transform(transformString: string): Transform };
export const config: Config;
export function noAuto():void;
export function findIconDefinition(iconLookup: IconLookup): IconDefinition;
export function text(content: string, params?: TextParams): Text;
export function counter(content: string | number, params?: CounterParams): Counter;
export function toHtml(content: any): string;
export function toHtml(abstractNodes: AbstractElement): string;
export function layer(
  assembler: (
    addLayerCallback: (layerToAdd: IconOrText | IconOrText[]) => void
  ) => void,
  params?: LayerParams
): Layer;
export function icon(icon: IconName | IconLookup, params?: IconParams): Icon;
export type IconProp = IconName | [IconPrefix, IconName] | IconLookup;
export type FlipProp = "horizontal" | "vertical" | "both";
export type SizeProp =
  | "xs"
  | "lg"
  | "sm"
  | "1x"
  | "2x"
  | "3x"
  | "4x"
  | "5x"
  | "6x"
  | "7x"
  | "8x"
  | "9x"
  | "10x";
export type PullProp = "left" | "right";
export type RotateProp = 90 | 180 | 270;
export type FaSymbol = string | boolean;
export interface Config {
  familyPrefix: IconPrefix;
  replacementClass: string;
  autoReplaceSvg: boolean | 'nest';
  autoAddCss: boolean;
  autoA11y: boolean;
  searchPseudoElements: boolean;
  observeMutations: boolean;
  keepOriginalSource: boolean;
  measurePerformance: boolean;
  showMissingIcons: boolean;
}
export interface AbstractElement {
  tag: string;
  attributes: any;
  children?: AbstractElement[];
}
export interface FontawesomeObject {
  readonly abstract: AbstractElement[];
  readonly html: string[];
  readonly node: HTMLCollection;
}
export interface Icon extends FontawesomeObject, IconDefinition {
  readonly type: "icon";
}
export interface Text extends FontawesomeObject {
  readonly type: "text";
}
export interface Counter extends FontawesomeObject {
  readonly type: "counter";
}
export interface Layer extends FontawesomeObject {
  readonly type: "layer";
}
type IconOrText = Icon | Text;
export interface Attributes {
  [key: string]: number | string;
}
export interface Styles {
  [key: string]: string;
}
export interface Transform {
  size?: number;
  x?: number;
  y?: number;
  rotate?: number;
  flipX?: boolean;
  flipY?: boolean;
}
export interface Params {
  title?: string;
  classes?: string | string[];
  attributes?: Attributes;
  styles?: Styles;
}
export interface CounterParams extends Params {
}
export interface LayerParams {
  classes?: string | string[];
}
export interface TextParams extends Params {
  transform?: Transform;
}
export interface IconParams extends Params {
  transform?: Transform;
  symbol?: FaSymbol;
  mask?: IconLookup;
}
export interface DOM {
  i2svg(params?: { node: Node; callback: () => void }): Promise<void>;
  css(): string;
  insertCss(): string;
  watch(): void;
}
type IconDefinitionOrPack = IconDefinition | IconPack;
export interface Library {
  add(...definitions: IconDefinitionOrPack[]): void;
  reset(): void;
}

/**
 * Brands Definitions
 */

export const fa500px: IconDefinition;
export const faAccessibleIcon: IconDefinition;
export const faAccusoft: IconDefinition;
export const faAcquisitionsIncorporated: IconDefinition;
export const faAdn: IconDefinition;
export const faAdobe: IconDefinition;
export const faAdversal: IconDefinition;
export const faAffiliatetheme: IconDefinition;
export const faAirbnb: IconDefinition;
export const faAlgolia: IconDefinition;
export const faAlipay: IconDefinition;
export const faAmazon: IconDefinition;
export const faAmazonPay: IconDefinition;
export const faAmilia: IconDefinition;
export const faAndroid: IconDefinition;
export const faAngellist: IconDefinition;
export const faAngrycreative: IconDefinition;
export const faAngular: IconDefinition;
export const faAppStore: IconDefinition;
export const faAppStoreIos: IconDefinition;
export const faApper: IconDefinition;
export const faApple: IconDefinition;
export const faApplePay: IconDefinition;
export const faArtstation: IconDefinition;
export const faAsymmetrik: IconDefinition;
export const faAtlassian: IconDefinition;
export const faAudible: IconDefinition;
export const faAutoprefixer: IconDefinition;
export const faAvianex: IconDefinition;
export const faAviato: IconDefinition;
export const faAws: IconDefinition;
export const faBandcamp: IconDefinition;
export const faBattleNet: IconDefinition;
export const faBehance: IconDefinition;
export const faBehanceSquare: IconDefinition;
export const faBimobject: IconDefinition;
export const faBitbucket: IconDefinition;
export const faBitcoin: IconDefinition;
export const faBity: IconDefinition;
export const faBlackTie: IconDefinition;
export const faBlackberry: IconDefinition;
export const faBlogger: IconDefinition;
export const faBloggerB: IconDefinition;
export const faBluetooth: IconDefinition;
export const faBluetoothB: IconDefinition;
export const faBootstrap: IconDefinition;
export const faBtc: IconDefinition;
export const faBuffer: IconDefinition;
export const faBuromobelexperte: IconDefinition;
export const faBuyNLarge: IconDefinition;
export const faBuysellads: IconDefinition;
export const faCanadianMapleLeaf: IconDefinition;
export const faCcAmazonPay: IconDefinition;
export const faCcAmex: IconDefinition;
export const faCcApplePay: IconDefinition;
export const faCcDinersClub: IconDefinition;
export const faCcDiscover: IconDefinition;
export const faCcJcb: IconDefinition;
export const faCcMastercard: IconDefinition;
export const faCcPaypal: IconDefinition;
export const faCcStripe: IconDefinition;
export const faCcVisa: IconDefinition;
export const faCentercode: IconDefinition;
export const faCentos: IconDefinition;
export const faChrome: IconDefinition;
export const faChromecast: IconDefinition;
export const faCloudscale: IconDefinition;
export const faCloudsmith: IconDefinition;
export const faCloudversify: IconDefinition;
export const faCodepen: IconDefinition;
export const faCodiepie: IconDefinition;
export const faConfluence: IconDefinition;
export const faConnectdevelop: IconDefinition;
export const faContao: IconDefinition;
export const faCottonBureau: IconDefinition;
export const faCpanel: IconDefinition;
export const faCreativeCommons: IconDefinition;
export const faCreativeCommonsBy: IconDefinition;
export const faCreativeCommonsNc: IconDefinition;
export const faCreativeCommonsNcEu: IconDefinition;
export const faCreativeCommonsNcJp: IconDefinition;
export const faCreativeCommonsNd: IconDefinition;
export const faCreativeCommonsPd: IconDefinition;
export const faCreativeCommonsPdAlt: IconDefinition;
export const faCreativeCommonsRemix: IconDefinition;
export const faCreativeCommonsSa: IconDefinition;
export const faCreativeCommonsSampling: IconDefinition;
export const faCreativeCommonsSamplingPlus: IconDefinition;
export const faCreativeCommonsShare: IconDefinition;
export const faCreativeCommonsZero: IconDefinition;
export const faCriticalRole: IconDefinition;
export const faCss3: IconDefinition;
export const faCss3Alt: IconDefinition;
export const faCuttlefish: IconDefinition;
export const faDAndD: IconDefinition;
export const faDAndDBeyond: IconDefinition;
export const faDailymotion: IconDefinition;
export const faDashcube: IconDefinition;
export const faDelicious: IconDefinition;
export const faDeploydog: IconDefinition;
export const faDeskpro: IconDefinition;
export const faDev: IconDefinition;
export const faDeviantart: IconDefinition;
export const faDhl: IconDefinition;
export const faDiaspora: IconDefinition;
export const faDigg: IconDefinition;
export const faDigitalOcean: IconDefinition;
export const faDiscord: IconDefinition;
export const faDiscourse: IconDefinition;
export const faDochub: IconDefinition;
export const faDocker: IconDefinition;
export const faDraft2digital: IconDefinition;
export const faDribbble: IconDefinition;
export const faDribbbleSquare: IconDefinition;
export const faDropbox: IconDefinition;
export const faDrupal: IconDefinition;
export const faDyalog: IconDefinition;
export const faEarlybirds: IconDefinition;
export const faEbay: IconDefinition;
export const faEdge: IconDefinition;
export const faElementor: IconDefinition;
export const faEllo: IconDefinition;
export const faEmber: IconDefinition;
export const faEmpire: IconDefinition;
export const faEnvira: IconDefinition;
export const faErlang: IconDefinition;
export const faEthereum: IconDefinition;
export const faEtsy: IconDefinition;
export const faEvernote: IconDefinition;
export const faExpeditedssl: IconDefinition;
export const faFacebook: IconDefinition;
export const faFacebookF: IconDefinition;
export const faFacebookMessenger: IconDefinition;
export const faFacebookSquare: IconDefinition;
export const faFantasyFlightGames: IconDefinition;
export const faFedex: IconDefinition;
export const faFedora: IconDefinition;
export const faFigma: IconDefinition;
export const faFirefox: IconDefinition;
export const faFirefoxBrowser: IconDefinition;
export const faFirstOrder: IconDefinition;
export const faFirstOrderAlt: IconDefinition;
export const faFirstdraft: IconDefinition;
export const faFlickr: IconDefinition;
export const faFlipboard: IconDefinition;
export const faFly: IconDefinition;
export const faFontAwesome: IconDefinition;
export const faFontAwesomeAlt: IconDefinition;
export const faFontAwesomeFlag: IconDefinition;
export const faFontAwesomeLogoFull: IconDefinition;
export const faFonticons: IconDefinition;
export const faFonticonsFi: IconDefinition;
export const faFortAwesome: IconDefinition;
export const faFortAwesomeAlt: IconDefinition;
export const faForumbee: IconDefinition;
export const faFoursquare: IconDefinition;
export const faFreeCodeCamp: IconDefinition;
export const faFreebsd: IconDefinition;
export const faFulcrum: IconDefinition;
export const faGalacticRepublic: IconDefinition;
export const faGalacticSenate: IconDefinition;
export const faGetPocket: IconDefinition;
export const faGg: IconDefinition;
export const faGgCircle: IconDefinition;
export const faGit: IconDefinition;
export const faGitAlt: IconDefinition;
export const faGitSquare: IconDefinition;
export const faGithub: IconDefinition;
export const faGithubAlt: IconDefinition;
export const faGithubSquare: IconDefinition;
export const faGitkraken: IconDefinition;
export const faGitlab: IconDefinition;
export const faGitter: IconDefinition;
export const faGlide: IconDefinition;
export const faGlideG: IconDefinition;
export const faGofore: IconDefinition;
export const faGoodreads: IconDefinition;
export const faGoodreadsG: IconDefinition;
export const faGoogle: IconDefinition;
export const faGoogleDrive: IconDefinition;
export const faGooglePlay: IconDefinition;
export const faGooglePlus: IconDefinition;
export const faGooglePlusG: IconDefinition;
export const faGooglePlusSquare: IconDefinition;
export const faGoogleWallet: IconDefinition;
export const faGratipay: IconDefinition;
export const faGrav: IconDefinition;
export const faGripfire: IconDefinition;
export const faGrunt: IconDefinition;
export const faGulp: IconDefinition;
export const faHackerNews: IconDefinition;
export const faHackerNewsSquare: IconDefinition;
export const faHackerrank: IconDefinition;
export const faHips: IconDefinition;
export const faHireAHelper: IconDefinition;
export const faHooli: IconDefinition;
export const faHornbill: IconDefinition;
export const faHotjar: IconDefinition;
export const faHouzz: IconDefinition;
export const faHtml5: IconDefinition;
export const faHubspot: IconDefinition;
export const faIdeal: IconDefinition;
export const faImdb: IconDefinition;
export const faInstagram: IconDefinition;
export const faInstagramSquare: IconDefinition;
export const faIntercom: IconDefinition;
export const faInternetExplorer: IconDefinition;
export const faInvision: IconDefinition;
export const faIoxhost: IconDefinition;
export const faItchIo: IconDefinition;
export const faItunes: IconDefinition;
export const faItunesNote: IconDefinition;
export const faJava: IconDefinition;
export const faJediOrder: IconDefinition;
export const faJenkins: IconDefinition;
export const faJira: IconDefinition;
export const faJoget: IconDefinition;
export const faJoomla: IconDefinition;
export const faJs: IconDefinition;
export const faJsSquare: IconDefinition;
export const faJsfiddle: IconDefinition;
export const faKaggle: IconDefinition;
export const faKeybase: IconDefinition;
export const faKeycdn: IconDefinition;
export const faKickstarter: IconDefinition;
export const faKickstarterK: IconDefinition;
export const faKorvue: IconDefinition;
export const faLaravel: IconDefinition;
export const faLastfm: IconDefinition;
export const faLastfmSquare: IconDefinition;
export const faLeanpub: IconDefinition;
export const faLess: IconDefinition;
export const faLine: IconDefinition;
export const faLinkedin: IconDefinition;
export const faLinkedinIn: IconDefinition;
export const faLinode: IconDefinition;
export const faLinux: IconDefinition;
export const faLyft: IconDefinition;
export const faMagento: IconDefinition;
export const faMailchimp: IconDefinition;
export const faMandalorian: IconDefinition;
export const faMarkdown: IconDefinition;
export const faMastodon: IconDefinition;
export const faMaxcdn: IconDefinition;
export const faMdb: IconDefinition;
export const faMedapps: IconDefinition;
export const faMedium: IconDefinition;
export const faMediumM: IconDefinition;
export const faMedrt: IconDefinition;
export const faMeetup: IconDefinition;
export const faMegaport: IconDefinition;
export const faMendeley: IconDefinition;
export const faMicroblog: IconDefinition;
export const faMicrosoft: IconDefinition;
export const faMix: IconDefinition;
export const faMixcloud: IconDefinition;
export const faMixer: IconDefinition;
export const faMizuni: IconDefinition;
export const faModx: IconDefinition;
export const faMonero: IconDefinition;
export const faNapster: IconDefinition;
export const faNeos: IconDefinition;
export const faNimblr: IconDefinition;
export const faNode: IconDefinition;
export const faNodeJs: IconDefinition;
export const faNpm: IconDefinition;
export const faNs8: IconDefinition;
export const faNutritionix: IconDefinition;
export const faOdnoklassniki: IconDefinition;
export const faOdnoklassnikiSquare: IconDefinition;
export const faOldRepublic: IconDefinition;
export const faOpencart: IconDefinition;
export const faOpenid: IconDefinition;
export const faOpera: IconDefinition;
export const faOptinMonster: IconDefinition;
export const faOrcid: IconDefinition;
export const faOsi: IconDefinition;
export const faPage4: IconDefinition;
export const faPagelines: IconDefinition;
export const faPalfed: IconDefinition;
export const faPatreon: IconDefinition;
export const faPaypal: IconDefinition;
export const faPennyArcade: IconDefinition;
export const faPeriscope: IconDefinition;
export const faPhabricator: IconDefinition;
export const faPhoenixFramework: IconDefinition;
export const faPhoenixSquadron: IconDefinition;
export const faPhp: IconDefinition;
export const faPiedPiper: IconDefinition;
export const faPiedPiperAlt: IconDefinition;
export const faPiedPiperHat: IconDefinition;
export const faPiedPiperPp: IconDefinition;
export const faPiedPiperSquare: IconDefinition;
export const faPinterest: IconDefinition;
export const faPinterestP: IconDefinition;
export const faPinterestSquare: IconDefinition;
export const faPlaystation: IconDefinition;
export const faProductHunt: IconDefinition;
export const faPushed: IconDefinition;
export const faPython: IconDefinition;
export const faQq: IconDefinition;
export const faQuinscape: IconDefinition;
export const faQuora: IconDefinition;
export const faRProject: IconDefinition;
export const faRaspberryPi: IconDefinition;
export const faRavelry: IconDefinition;
export const faReact: IconDefinition;
export const faReacteurope: IconDefinition;
export const faReadme: IconDefinition;
export const faRebel: IconDefinition;
export const faRedRiver: IconDefinition;
export const faReddit: IconDefinition;
export const faRedditAlien: IconDefinition;
export const faRedditSquare: IconDefinition;
export const faRedhat: IconDefinition;
export const faRenren: IconDefinition;
export const faReplyd: IconDefinition;
export const faResearchgate: IconDefinition;
export const faResolving: IconDefinition;
export const faRev: IconDefinition;
export const faRocketchat: IconDefinition;
export const faRockrms: IconDefinition;
export const faSafari: IconDefinition;
export const faSalesforce: IconDefinition;
export const faSass: IconDefinition;
export const faSchlix: IconDefinition;
export const faScribd: IconDefinition;
export const faSearchengin: IconDefinition;
export const faSellcast: IconDefinition;
export const faSellsy: IconDefinition;
export const faServicestack: IconDefinition;
export const faShirtsinbulk: IconDefinition;
export const faShopify: IconDefinition;
export const faShopware: IconDefinition;
export const faSimplybuilt: IconDefinition;
export const faSistrix: IconDefinition;
export const faSith: IconDefinition;
export const faSketch: IconDefinition;
export const faSkyatlas: IconDefinition;
export const faSkype: IconDefinition;
export const faSlack: IconDefinition;
export const faSlackHash: IconDefinition;
export const faSlideshare: IconDefinition;
export const faSnapchat: IconDefinition;
export const faSnapchatGhost: IconDefinition;
export const faSnapchatSquare: IconDefinition;
export const faSoundcloud: IconDefinition;
export const faSourcetree: IconDefinition;
export const faSpeakap: IconDefinition;
export const faSpeakerDeck: IconDefinition;
export const faSpotify: IconDefinition;
export const faSquarespace: IconDefinition;
export const faStackExchange: IconDefinition;
export const faStackOverflow: IconDefinition;
export const faStackpath: IconDefinition;
export const faStaylinked: IconDefinition;
export const faSteam: IconDefinition;
export const faSteamSquare: IconDefinition;
export const faSteamSymbol: IconDefinition;
export const faStickerMule: IconDefinition;
export const faStrava: IconDefinition;
export const faStripe: IconDefinition;
export const faStripeS: IconDefinition;
export const faStudiovinari: IconDefinition;
export const faStumbleupon: IconDefinition;
export const faStumbleuponCircle: IconDefinition;
export const faSuperpowers: IconDefinition;
export const faSupple: IconDefinition;
export const faSuse: IconDefinition;
export const faSwift: IconDefinition;
export const faSymfony: IconDefinition;
export const faTeamspeak: IconDefinition;
export const faTelegram: IconDefinition;
export const faTelegramPlane: IconDefinition;
export const faTencentWeibo: IconDefinition;
export const faTheRedYeti: IconDefinition;
export const faThemeco: IconDefinition;
export const faThemeisle: IconDefinition;
export const faThinkPeaks: IconDefinition;
export const faTradeFederation: IconDefinition;
export const faTrello: IconDefinition;
export const faTripadvisor: IconDefinition;
export const faTumblr: IconDefinition;
export const faTumblrSquare: IconDefinition;
export const faTwitch: IconDefinition;
export const faTwitter: IconDefinition;
export const faTwitterSquare: IconDefinition;
export const faTypo3: IconDefinition;
export const faUber: IconDefinition;
export const faUbuntu: IconDefinition;
export const faUikit: IconDefinition;
export const faUmbraco: IconDefinition;
export const faUniregistry: IconDefinition;
export const faUnity: IconDefinition;
export const faUntappd: IconDefinition;
export const faUps: IconDefinition;
export const faUsb: IconDefinition;
export const faUsps: IconDefinition;
export const faUssunnah: IconDefinition;
export const faVaadin: IconDefinition;
export const faViacoin: IconDefinition;
export const faViadeo: IconDefinition;
export const faViadeoSquare: IconDefinition;
export const faViber: IconDefinition;
export const faVimeo: IconDefinition;
export const faVimeoSquare: IconDefinition;
export const faVimeoV: IconDefinition;
export const faVine: IconDefinition;
export const faVk: IconDefinition;
export const faVnv: IconDefinition;
export const faVuejs: IconDefinition;
export const faWaze: IconDefinition;
export const faWeebly: IconDefinition;
export const faWeibo: IconDefinition;
export const faWeixin: IconDefinition;
export const faWhatsapp: IconDefinition;
export const faWhatsappSquare: IconDefinition;
export const faWhmcs: IconDefinition;
export const faWikipediaW: IconDefinition;
export const faWindows: IconDefinition;
export const faWix: IconDefinition;
export const faWizardsOfTheCoast: IconDefinition;
export const faWolfPackBattalion: IconDefinition;
export const faWordpress: IconDefinition;
export const faWordpressSimple: IconDefinition;
export const faWpbeginner: IconDefinition;
export const faWpexplorer: IconDefinition;
export const faWpforms: IconDefinition;
export const faWpressr: IconDefinition;
export const faXbox: IconDefinition;
export const faXing: IconDefinition;
export const faXingSquare: IconDefinition;
export const faYCombinator: IconDefinition;
export const faYahoo: IconDefinition;
export const faYammer: IconDefinition;
export const faYandex: IconDefinition;
export const faYandexInternational: IconDefinition;
export const faYarn: IconDefinition;
export const faYelp: IconDefinition;
export const faYoast: IconDefinition;
export const faYoutube: IconDefinition;
export const faYoutubeSquare: IconDefinition;
export const faZhihu: IconDefinition;
export const fab: IconPack;

/**
 * Solid SVG Definitions
 */

export const faAd: IconDefinition;
export const faAddressBook: IconDefinition;
export const faAddressCard: IconDefinition;
export const faAdjust: IconDefinition;
export const faAirFreshener: IconDefinition;
export const faAlignCenter: IconDefinition;
export const faAlignJustify: IconDefinition;
export const faAlignLeft: IconDefinition;
export const faAlignRight: IconDefinition;
export const faAllergies: IconDefinition;
export const faAmbulance: IconDefinition;
export const faAmericanSignLanguageInterpreting: IconDefinition;
export const faAnchor: IconDefinition;
export const faAngleDoubleDown: IconDefinition;
export const faAngleDoubleLeft: IconDefinition;
export const faAngleDoubleRight: IconDefinition;
export const faAngleDoubleUp: IconDefinition;
export const faAngleDown: IconDefinition;
export const faAngleLeft: IconDefinition;
export const faAngleRight: IconDefinition;
export const faAngleUp: IconDefinition;
export const faAngry: IconDefinition;
export const faAnkh: IconDefinition;
export const faAppleAlt: IconDefinition;
export const faArchive: IconDefinition;
export const faArchway: IconDefinition;
export const faArrowAltCircleDown: IconDefinition;
export const faArrowAltCircleLeft: IconDefinition;
export const faArrowAltCircleRight: IconDefinition;
export const faArrowAltCircleUp: IconDefinition;
export const faArrowCircleDown: IconDefinition;
export const faArrowCircleLeft: IconDefinition;
export const faArrowCircleRight: IconDefinition;
export const faArrowCircleUp: IconDefinition;
export const faArrowDown: IconDefinition;
export const faArrowLeft: IconDefinition;
export const faArrowRight: IconDefinition;
export const faArrowUp: IconDefinition;
export const faArrowsAlt: IconDefinition;
export const faArrowsAltH: IconDefinition;
export const faArrowsAltV: IconDefinition;
export const faAssistiveListeningSystems: IconDefinition;
export const faAsterisk: IconDefinition;
export const faAt: IconDefinition;
export const faAtlas: IconDefinition;
export const faAtom: IconDefinition;
export const faAudioDescription: IconDefinition;
export const faAward: IconDefinition;
export const faBaby: IconDefinition;
export const faBabyCarriage: IconDefinition;
export const faBackspace: IconDefinition;
export const faBackward: IconDefinition;
export const faBacon: IconDefinition;
export const faBahai: IconDefinition;
export const faBalanceScale: IconDefinition;
export const faBalanceScaleLeft: IconDefinition;
export const faBalanceScaleRight: IconDefinition;
export const faBan: IconDefinition;
export const faBandAid: IconDefinition;
export const faBarcode: IconDefinition;
export const faBars: IconDefinition;
export const faBaseballBall: IconDefinition;
export const faBasketballBall: IconDefinition;
export const faBath: IconDefinition;
export const faBatteryEmpty: IconDefinition;
export const faBatteryFull: IconDefinition;
export const faBatteryHalf: IconDefinition;
export const faBatteryQuarter: IconDefinition;
export const faBatteryThreeQuarters: IconDefinition;
export const faBed: IconDefinition;
export const faBeer: IconDefinition;
export const faBell: IconDefinition;
export const faBellSlash: IconDefinition;
export const faBezierCurve: IconDefinition;
export const faBible: IconDefinition;
export const faBicycle: IconDefinition;
export const faBiking: IconDefinition;
export const faBinoculars: IconDefinition;
export const faBiohazard: IconDefinition;
export const faBirthdayCake: IconDefinition;
export const faBlender: IconDefinition;
export const faBlenderPhone: IconDefinition;
export const faBlind: IconDefinition;
export const faBlog: IconDefinition;
export const faBold: IconDefinition;
export const faBolt: IconDefinition;
export const faBomb: IconDefinition;
export const faBone: IconDefinition;
export const faBong: IconDefinition;
export const faBook: IconDefinition;
export const faBookDead: IconDefinition;
export const faBookMedical: IconDefinition;
export const faBookOpen: IconDefinition;
export const faBookReader: IconDefinition;
export const faBookmark: IconDefinition;
export const faBorderAll: IconDefinition;
export const faBorderNone: IconDefinition;
export const faBorderStyle: IconDefinition;
export const faBowlingBall: IconDefinition;
export const faBox: IconDefinition;
export const faBoxOpen: IconDefinition;
export const faBoxes: IconDefinition;
export const faBraille: IconDefinition;
export const faBrain: IconDefinition;
export const faBreadSlice: IconDefinition;
export const faBriefcase: IconDefinition;
export const faBriefcaseMedical: IconDefinition;
export const faBroadcastTower: IconDefinition;
export const faBroom: IconDefinition;
export const faBrush: IconDefinition;
export const faBug: IconDefinition;
export const faBuilding: IconDefinition;
export const faBullhorn: IconDefinition;
export const faBullseye: IconDefinition;
export const faBurn: IconDefinition;
export const faBus: IconDefinition;
export const faBusAlt: IconDefinition;
export const faBusinessTime: IconDefinition;
export const faCalculator: IconDefinition;
export const faCalendar: IconDefinition;
export const faCalendarAlt: IconDefinition;
export const faCalendarCheck: IconDefinition;
export const faCalendarDay: IconDefinition;
export const faCalendarMinus: IconDefinition;
export const faCalendarPlus: IconDefinition;
export const faCalendarTimes: IconDefinition;
export const faCalendarWeek: IconDefinition;
export const faCamera: IconDefinition;
export const faCameraRetro: IconDefinition;
export const faCampground: IconDefinition;
export const faCandyCane: IconDefinition;
export const faCannabis: IconDefinition;
export const faCapsules: IconDefinition;
export const faCar: IconDefinition;
export const faCarAlt: IconDefinition;
export const faCarBattery: IconDefinition;
export const faCarCrash: IconDefinition;
export const faCarSide: IconDefinition;
export const faCaravan: IconDefinition;
export const faCaretDown: IconDefinition;
export const faCaretLeft: IconDefinition;
export const faCaretRight: IconDefinition;
export const faCaretSquareDown: IconDefinition;
export const faCaretSquareLeft: IconDefinition;
export const faCaretSquareRight: IconDefinition;
export const faCaretSquareUp: IconDefinition;
export const faCaretUp: IconDefinition;
export const faCarrot: IconDefinition;
export const faCartArrowDown: IconDefinition;
export const faCartPlus: IconDefinition;
export const faCashRegister: IconDefinition;
export const faCat: IconDefinition;
export const faCertificate: IconDefinition;
export const faChair: IconDefinition;
export const faChalkboard: IconDefinition;
export const faChalkboardTeacher: IconDefinition;
export const faChargingStation: IconDefinition;
export const faChartArea: IconDefinition;
export const faChartBar: IconDefinition;
export const faChartLine: IconDefinition;
export const faChartPie: IconDefinition;
export const faCheck: IconDefinition;
export const faCheckCircle: IconDefinition;
export const faCheckDouble: IconDefinition;
export const faCheckSquare: IconDefinition;
export const faCheese: IconDefinition;
export const faChess: IconDefinition;
export const faChessBishop: IconDefinition;
export const faChessBoard: IconDefinition;
export const faChessKing: IconDefinition;
export const faChessKnight: IconDefinition;
export const faChessPawn: IconDefinition;
export const faChessQueen: IconDefinition;
export const faChessRook: IconDefinition;
export const faChevronCircleDown: IconDefinition;
export const faChevronCircleLeft: IconDefinition;
export const faChevronCircleRight: IconDefinition;
export const faChevronCircleUp: IconDefinition;
export const faChevronDown: IconDefinition;
export const faChevronLeft: IconDefinition;
export const faChevronRight: IconDefinition;
export const faChevronUp: IconDefinition;
export const faChild: IconDefinition;
export const faChurch: IconDefinition;
export const faCircle: IconDefinition;
export const faCircleNotch: IconDefinition;
export const faCity: IconDefinition;
export const faClinicMedical: IconDefinition;
export const faClipboard: IconDefinition;
export const faClipboardCheck: IconDefinition;
export const faClipboardList: IconDefinition;
export const faClock: IconDefinition;
export const faClone: IconDefinition;
export const faClosedCaptioning: IconDefinition;
export const faCloud: IconDefinition;
export const faCloudDownloadAlt: IconDefinition;
export const faCloudMeatball: IconDefinition;
export const faCloudMoon: IconDefinition;
export const faCloudMoonRain: IconDefinition;
export const faCloudRain: IconDefinition;
export const faCloudShowersHeavy: IconDefinition;
export const faCloudSun: IconDefinition;
export const faCloudSunRain: IconDefinition;
export const faCloudUploadAlt: IconDefinition;
export const faCocktail: IconDefinition;
export const faCode: IconDefinition;
export const faCodeBranch: IconDefinition;
export const faCoffee: IconDefinition;
export const faCog: IconDefinition;
export const faCogs: IconDefinition;
export const faCoins: IconDefinition;
export const faColumns: IconDefinition;
export const faComment: IconDefinition;
export const faCommentAlt: IconDefinition;
export const faCommentDollar: IconDefinition;
export const faCommentDots: IconDefinition;
export const faCommentMedical: IconDefinition;
export const faCommentSlash: IconDefinition;
export const faComments: IconDefinition;
export const faCommentsDollar: IconDefinition;
export const faCompactDisc: IconDefinition;
export const faCompass: IconDefinition;
export const faCompress: IconDefinition;
export const faCompressAlt: IconDefinition;
export const faCompressArrowsAlt: IconDefinition;
export const faConciergeBell: IconDefinition;
export const faCookie: IconDefinition;
export const faCookieBite: IconDefinition;
export const faCopy: IconDefinition;
export const faCopyright: IconDefinition;
export const faCouch: IconDefinition;
export const faCreditCard: IconDefinition;
export const faCrop: IconDefinition;
export const faCropAlt: IconDefinition;
export const faCross: IconDefinition;
export const faCrosshairs: IconDefinition;
export const faCrow: IconDefinition;
export const faCrown: IconDefinition;
export const faCrutch: IconDefinition;
export const faCube: IconDefinition;
export const faCubes: IconDefinition;
export const faCut: IconDefinition;
export const faDatabase: IconDefinition;
export const faDeaf: IconDefinition;
export const faDemocrat: IconDefinition;
export const faDesktop: IconDefinition;
export const faDharmachakra: IconDefinition;
export const faDiagnoses: IconDefinition;
export const faDice: IconDefinition;
export const faDiceD20: IconDefinition;
export const faDiceD6: IconDefinition;
export const faDiceFive: IconDefinition;
export const faDiceFour: IconDefinition;
export const faDiceOne: IconDefinition;
export const faDiceSix: IconDefinition;
export const faDiceThree: IconDefinition;
export const faDiceTwo: IconDefinition;
export const faDigitalTachograph: IconDefinition;
export const faDirections: IconDefinition;
export const faDivide: IconDefinition;
export const faDizzy: IconDefinition;
export const faDna: IconDefinition;
export const faDog: IconDefinition;
export const faDollarSign: IconDefinition;
export const faDolly: IconDefinition;
export const faDollyFlatbed: IconDefinition;
export const faDonate: IconDefinition;
export const faDoorClosed: IconDefinition;
export const faDoorOpen: IconDefinition;
export const faDotCircle: IconDefinition;
export const faDove: IconDefinition;
export const faDownload: IconDefinition;
export const faDraftingCompass: IconDefinition;
export const faDragon: IconDefinition;
export const faDrawPolygon: IconDefinition;
export const faDrum: IconDefinition;
export const faDrumSteelpan: IconDefinition;
export const faDrumstickBite: IconDefinition;
export const faDumbbell: IconDefinition;
export const faDumpster: IconDefinition;
export const faDumpsterFire: IconDefinition;
export const faDungeon: IconDefinition;
export const faEdit: IconDefinition;
export const faEgg: IconDefinition;
export const faEject: IconDefinition;
export const faEllipsisH: IconDefinition;
export const faEllipsisV: IconDefinition;
export const faEnvelope: IconDefinition;
export const faEnvelopeOpen: IconDefinition;
export const faEnvelopeOpenText: IconDefinition;
export const faEnvelopeSquare: IconDefinition;
export const faEquals: IconDefinition;
export const faEraser: IconDefinition;
export const faEthernet: IconDefinition;
export const faEuroSign: IconDefinition;
export const faExchangeAlt: IconDefinition;
export const faExclamation: IconDefinition;
export const faExclamationCircle: IconDefinition;
export const faExclamationTriangle: IconDefinition;
export const faExpand: IconDefinition;
export const faExpandAlt: IconDefinition;
export const faExpandArrowsAlt: IconDefinition;
export const faExternalLinkAlt: IconDefinition;
export const faExternalLinkSquareAlt: IconDefinition;
export const faEye: IconDefinition;
export const faEyeDropper: IconDefinition;
export const faEyeSlash: IconDefinition;
export const faFan: IconDefinition;
export const faFastBackward: IconDefinition;
export const faFastForward: IconDefinition;
export const faFax: IconDefinition;
export const faFeather: IconDefinition;
export const faFeatherAlt: IconDefinition;
export const faFemale: IconDefinition;
export const faFighterJet: IconDefinition;
export const faFile: IconDefinition;
export const faFileAlt: IconDefinition;
export const faFileArchive: IconDefinition;
export const faFileAudio: IconDefinition;
export const faFileCode: IconDefinition;
export const faFileContract: IconDefinition;
export const faFileCsv: IconDefinition;
export const faFileDownload: IconDefinition;
export const faFileExcel: IconDefinition;
export const faFileExport: IconDefinition;
export const faFileImage: IconDefinition;
export const faFileImport: IconDefinition;
export const faFileInvoice: IconDefinition;
export const faFileInvoiceDollar: IconDefinition;
export const faFileMedical: IconDefinition;
export const faFileMedicalAlt: IconDefinition;
export const faFilePdf: IconDefinition;
export const faFilePowerpoint: IconDefinition;
export const faFilePrescription: IconDefinition;
export const faFileSignature: IconDefinition;
export const faFileUpload: IconDefinition;
export const faFileVideo: IconDefinition;
export const faFileWord: IconDefinition;
export const faFill: IconDefinition;
export const faFillDrip: IconDefinition;
export const faFilm: IconDefinition;
export const faFilter: IconDefinition;
export const faFingerprint: IconDefinition;
export const faFire: IconDefinition;
export const faFireAlt: IconDefinition;
export const faFireExtinguisher: IconDefinition;
export const faFirstAid: IconDefinition;
export const faFish: IconDefinition;
export const faFistRaised: IconDefinition;
export const faFlag: IconDefinition;
export const faFlagCheckered: IconDefinition;
export const faFlagUsa: IconDefinition;
export const faFlask: IconDefinition;
export const faFlushed: IconDefinition;
export const faFolder: IconDefinition;
export const faFolderMinus: IconDefinition;
export const faFolderOpen: IconDefinition;
export const faFolderPlus: IconDefinition;
export const faFont: IconDefinition;
export const faFootballBall: IconDefinition;
export const faForward: IconDefinition;
export const faFrog: IconDefinition;
export const faFrown: IconDefinition;
export const faFrownOpen: IconDefinition;
export const faFunnelDollar: IconDefinition;
export const faFutbol: IconDefinition;
export const faGamepad: IconDefinition;
export const faGasPump: IconDefinition;
export const faGavel: IconDefinition;
export const faGem: IconDefinition;
export const faGenderless: IconDefinition;
export const faGhost: IconDefinition;
export const faGift: IconDefinition;
export const faGifts: IconDefinition;
export const faGlassCheers: IconDefinition;
export const faGlassMartini: IconDefinition;
export const faGlassMartiniAlt: IconDefinition;
export const faGlassWhiskey: IconDefinition;
export const faGlasses: IconDefinition;
export const faGlobe: IconDefinition;
export const faGlobeAfrica: IconDefinition;
export const faGlobeAmericas: IconDefinition;
export const faGlobeAsia: IconDefinition;
export const faGlobeEurope: IconDefinition;
export const faGolfBall: IconDefinition;
export const faGopuram: IconDefinition;
export const faGraduationCap: IconDefinition;
export const faGreaterThan: IconDefinition;
export const faGreaterThanEqual: IconDefinition;
export const faGrimace: IconDefinition;
export const faGrin: IconDefinition;
export const faGrinAlt: IconDefinition;
export const faGrinBeam: IconDefinition;
export const faGrinBeamSweat: IconDefinition;
export const faGrinHearts: IconDefinition;
export const faGrinSquint: IconDefinition;
export const faGrinSquintTears: IconDefinition;
export const faGrinStars: IconDefinition;
export const faGrinTears: IconDefinition;
export const faGrinTongue: IconDefinition;
export const faGrinTongueSquint: IconDefinition;
export const faGrinTongueWink: IconDefinition;
export const faGrinWink: IconDefinition;
export const faGripHorizontal: IconDefinition;
export const faGripLines: IconDefinition;
export const faGripLinesVertical: IconDefinition;
export const faGripVertical: IconDefinition;
export const faGuitar: IconDefinition;
export const faHSquare: IconDefinition;
export const faHamburger: IconDefinition;
export const faHammer: IconDefinition;
export const faHamsa: IconDefinition;
export const faHandHolding: IconDefinition;
export const faHandHoldingHeart: IconDefinition;
export const faHandHoldingUsd: IconDefinition;
export const faHandLizard: IconDefinition;
export const faHandMiddleFinger: IconDefinition;
export const faHandPaper: IconDefinition;
export const faHandPeace: IconDefinition;
export const faHandPointDown: IconDefinition;
export const faHandPointLeft: IconDefinition;
export const faHandPointRight: IconDefinition;
export const faHandPointUp: IconDefinition;
export const faHandPointer: IconDefinition;
export const faHandRock: IconDefinition;
export const faHandScissors: IconDefinition;
export const faHandSpock: IconDefinition;
export const faHands: IconDefinition;
export const faHandsHelping: IconDefinition;
export const faHandshake: IconDefinition;
export const faHanukiah: IconDefinition;
export const faHardHat: IconDefinition;
export const faHashtag: IconDefinition;
export const faHatCowboy: IconDefinition;
export const faHatCowboySide: IconDefinition;
export const faHatWizard: IconDefinition;
export const faHdd: IconDefinition;
export const faHeading: IconDefinition;
export const faHeadphones: IconDefinition;
export const faHeadphonesAlt: IconDefinition;
export const faHeadset: IconDefinition;
export const faHeart: IconDefinition;
export const faHeartBroken: IconDefinition;
export const faHeartbeat: IconDefinition;
export const faHelicopter: IconDefinition;
export const faHighlighter: IconDefinition;
export const faHiking: IconDefinition;
export const faHippo: IconDefinition;
export const faHistory: IconDefinition;
export const faHockeyPuck: IconDefinition;
export const faHollyBerry: IconDefinition;
export const faHome: IconDefinition;
export const faHorse: IconDefinition;
export const faHorseHead: IconDefinition;
export const faHospital: IconDefinition;
export const faHospitalAlt: IconDefinition;
export const faHospitalSymbol: IconDefinition;
export const faHotTub: IconDefinition;
export const faHotdog: IconDefinition;
export const faHotel: IconDefinition;
export const faHourglass: IconDefinition;
export const faHourglassEnd: IconDefinition;
export const faHourglassHalf: IconDefinition;
export const faHourglassStart: IconDefinition;
export const faHouseDamage: IconDefinition;
export const faHryvnia: IconDefinition;
export const faICursor: IconDefinition;
export const faIceCream: IconDefinition;
export const faIcicles: IconDefinition;
export const faIcons: IconDefinition;
export const faIdBadge: IconDefinition;
export const faIdCard: IconDefinition;
export const faIdCardAlt: IconDefinition;
export const faIgloo: IconDefinition;
export const faImage: IconDefinition;
export const faImages: IconDefinition;
export const faInbox: IconDefinition;
export const faIndent: IconDefinition;
export const faIndustry: IconDefinition;
export const faInfinity: IconDefinition;
export const faInfo: IconDefinition;
export const faInfoCircle: IconDefinition;
export const faItalic: IconDefinition;
export const faJedi: IconDefinition;
export const faJoint: IconDefinition;
export const faJournalWhills: IconDefinition;
export const faKaaba: IconDefinition;
export const faKey: IconDefinition;
export const faKeyboard: IconDefinition;
export const faKhanda: IconDefinition;
export const faKiss: IconDefinition;
export const faKissBeam: IconDefinition;
export const faKissWinkHeart: IconDefinition;
export const faKiwiBird: IconDefinition;
export const faLandmark: IconDefinition;
export const faLanguage: IconDefinition;
export const faLaptop: IconDefinition;
export const faLaptopCode: IconDefinition;
export const faLaptopMedical: IconDefinition;
export const faLaugh: IconDefinition;
export const faLaughBeam: IconDefinition;
export const faLaughSquint: IconDefinition;
export const faLaughWink: IconDefinition;
export const faLayerGroup: IconDefinition;
export const faLeaf: IconDefinition;
export const faLemon: IconDefinition;
export const faLessThan: IconDefinition;
export const faLessThanEqual: IconDefinition;
export const faLevelDownAlt: IconDefinition;
export const faLevelUpAlt: IconDefinition;
export const faLifeRing: IconDefinition;
export const faLightbulb: IconDefinition;
export const faLink: IconDefinition;
export const faLiraSign: IconDefinition;
export const faList: IconDefinition;
export const faListAlt: IconDefinition;
export const faListOl: IconDefinition;
export const faListUl: IconDefinition;
export const faLocationArrow: IconDefinition;
export const faLock: IconDefinition;
export const faLockOpen: IconDefinition;
export const faLongArrowAltDown: IconDefinition;
export const faLongArrowAltLeft: IconDefinition;
export const faLongArrowAltRight: IconDefinition;
export const faLongArrowAltUp: IconDefinition;
export const faLowVision: IconDefinition;
export const faLuggageCart: IconDefinition;
export const faMagic: IconDefinition;
export const faMagnet: IconDefinition;
export const faMailBulk: IconDefinition;
export const faMale: IconDefinition;
export const faMap: IconDefinition;
export const faMapMarked: IconDefinition;
export const faMapMarkedAlt: IconDefinition;
export const faMapMarker: IconDefinition;
export const faMapMarkerAlt: IconDefinition;
export const faMapPin: IconDefinition;
export const faMapSigns: IconDefinition;
export const faMarker: IconDefinition;
export const faMars: IconDefinition;
export const faMarsDouble: IconDefinition;
export const faMarsStroke: IconDefinition;
export const faMarsStrokeH: IconDefinition;
export const faMarsStrokeV: IconDefinition;
export const faMask: IconDefinition;
export const faMedal: IconDefinition;
export const faMedkit: IconDefinition;
export const faMeh: IconDefinition;
export const faMehBlank: IconDefinition;
export const faMehRollingEyes: IconDefinition;
export const faMemory: IconDefinition;
export const faMenorah: IconDefinition;
export const faMercury: IconDefinition;
export const faMeteor: IconDefinition;
export const faMicrochip: IconDefinition;
export const faMicrophone: IconDefinition;
export const faMicrophoneAlt: IconDefinition;
export const faMicrophoneAltSlash: IconDefinition;
export const faMicrophoneSlash: IconDefinition;
export const faMicroscope: IconDefinition;
export const faMinus: IconDefinition;
export const faMinusCircle: IconDefinition;
export const faMinusSquare: IconDefinition;
export const faMitten: IconDefinition;
export const faMobile: IconDefinition;
export const faMobileAlt: IconDefinition;
export const faMoneyBill: IconDefinition;
export const faMoneyBillAlt: IconDefinition;
export const faMoneyBillWave: IconDefinition;
export const faMoneyBillWaveAlt: IconDefinition;
export const faMoneyCheck: IconDefinition;
export const faMoneyCheckAlt: IconDefinition;
export const faMonument: IconDefinition;
export const faMoon: IconDefinition;
export const faMortarPestle: IconDefinition;
export const faMosque: IconDefinition;
export const faMotorcycle: IconDefinition;
export const faMountain: IconDefinition;
export const faMouse: IconDefinition;
export const faMousePointer: IconDefinition;
export const faMugHot: IconDefinition;
export const faMusic: IconDefinition;
export const faNetworkWired: IconDefinition;
export const faNeuter: IconDefinition;
export const faNewspaper: IconDefinition;
export const faNotEqual: IconDefinition;
export const faNotesMedical: IconDefinition;
export const faObjectGroup: IconDefinition;
export const faObjectUngroup: IconDefinition;
export const faOilCan: IconDefinition;
export const faOm: IconDefinition;
export const faOtter: IconDefinition;
export const faOutdent: IconDefinition;
export const faPager: IconDefinition;
export const faPaintBrush: IconDefinition;
export const faPaintRoller: IconDefinition;
export const faPalette: IconDefinition;
export const faPallet: IconDefinition;
export const faPaperPlane: IconDefinition;
export const faPaperclip: IconDefinition;
export const faParachuteBox: IconDefinition;
export const faParagraph: IconDefinition;
export const faParking: IconDefinition;
export const faPassport: IconDefinition;
export const faPastafarianism: IconDefinition;
export const faPaste: IconDefinition;
export const faPause: IconDefinition;
export const faPauseCircle: IconDefinition;
export const faPaw: IconDefinition;
export const faPeace: IconDefinition;
export const faPen: IconDefinition;
export const faPenAlt: IconDefinition;
export const faPenFancy: IconDefinition;
export const faPenNib: IconDefinition;
export const faPenSquare: IconDefinition;
export const faPencilAlt: IconDefinition;
export const faPencilRuler: IconDefinition;
export const faPeopleCarry: IconDefinition;
export const faPepperHot: IconDefinition;
export const faPercent: IconDefinition;
export const faPercentage: IconDefinition;
export const faPersonBooth: IconDefinition;
export const faPhone: IconDefinition;
export const faPhoneAlt: IconDefinition;
export const faPhoneSlash: IconDefinition;
export const faPhoneSquare: IconDefinition;
export const faPhoneSquareAlt: IconDefinition;
export const faPhoneVolume: IconDefinition;
export const faPhotoVideo: IconDefinition;
export const faPiggyBank: IconDefinition;
export const faPills: IconDefinition;
export const faPizzaSlice: IconDefinition;
export const faPlaceOfWorship: IconDefinition;
export const faPlane: IconDefinition;
export const faPlaneArrival: IconDefinition;
export const faPlaneDeparture: IconDefinition;
export const faPlay: IconDefinition;
export const faPlayCircle: IconDefinition;
export const faPlug: IconDefinition;
export const faPlus: IconDefinition;
export const faPlusCircle: IconDefinition;
export const faPlusSquare: IconDefinition;
export const faPodcast: IconDefinition;
export const faPoll: IconDefinition;
export const faPollH: IconDefinition;
export const faPoo: IconDefinition;
export const faPooStorm: IconDefinition;
export const faPoop: IconDefinition;
export const faPortrait: IconDefinition;
export const faPoundSign: IconDefinition;
export const faPowerOff: IconDefinition;
export const faPray: IconDefinition;
export const faPrayingHands: IconDefinition;
export const faPrescription: IconDefinition;
export const faPrescriptionBottle: IconDefinition;
export const faPrescriptionBottleAlt: IconDefinition;
export const faPrint: IconDefinition;
export const faProcedures: IconDefinition;
export const faProjectDiagram: IconDefinition;
export const faPuzzlePiece: IconDefinition;
export const faQrcode: IconDefinition;
export const faQuestion: IconDefinition;
export const faQuestionCircle: IconDefinition;
export const faQuidditch: IconDefinition;
export const faQuoteLeft: IconDefinition;
export const faQuoteRight: IconDefinition;
export const faQuran: IconDefinition;
export const faRadiation: IconDefinition;
export const faRadiationAlt: IconDefinition;
export const faRainbow: IconDefinition;
export const faRandom: IconDefinition;
export const faReceipt: IconDefinition;
export const faRecordVinyl: IconDefinition;
export const faRecycle: IconDefinition;
export const faRedo: IconDefinition;
export const faRedoAlt: IconDefinition;
export const faRegistered: IconDefinition;
export const faRemoveFormat: IconDefinition;
export const faReply: IconDefinition;
export const faReplyAll: IconDefinition;
export const faRepublican: IconDefinition;
export const faRestroom: IconDefinition;
export const faRetweet: IconDefinition;
export const faRibbon: IconDefinition;
export const faRing: IconDefinition;
export const faRoad: IconDefinition;
export const faRobot: IconDefinition;
export const faRocket: IconDefinition;
export const faRoute: IconDefinition;
export const faRss: IconDefinition;
export const faRssSquare: IconDefinition;
export const faRubleSign: IconDefinition;
export const faRuler: IconDefinition;
export const faRulerCombined: IconDefinition;
export const faRulerHorizontal: IconDefinition;
export const faRulerVertical: IconDefinition;
export const faRunning: IconDefinition;
export const faRupeeSign: IconDefinition;
export const faSadCry: IconDefinition;
export const faSadTear: IconDefinition;
export const faSatellite: IconDefinition;
export const faSatelliteDish: IconDefinition;
export const faSave: IconDefinition;
export const faSchool: IconDefinition;
export const faScrewdriver: IconDefinition;
export const faScroll: IconDefinition;
export const faSdCard: IconDefinition;
export const faSearch: IconDefinition;
export const faSearchDollar: IconDefinition;
export const faSearchLocation: IconDefinition;
export const faSearchMinus: IconDefinition;
export const faSearchPlus: IconDefinition;
export const faSeedling: IconDefinition;
export const faServer: IconDefinition;
export const faShapes: IconDefinition;
export const faShare: IconDefinition;
export const faShareAlt: IconDefinition;
export const faShareAltSquare: IconDefinition;
export const faShareSquare: IconDefinition;
export const faShekelSign: IconDefinition;
export const faShieldAlt: IconDefinition;
export const faShip: IconDefinition;
export const faShippingFast: IconDefinition;
export const faShoePrints: IconDefinition;
export const faShoppingBag: IconDefinition;
export const faShoppingBasket: IconDefinition;
export const faShoppingCart: IconDefinition;
export const faShower: IconDefinition;
export const faShuttleVan: IconDefinition;
export const faSign: IconDefinition;
export const faSignInAlt: IconDefinition;
export const faSignLanguage: IconDefinition;
export const faSignOutAlt: IconDefinition;
export const faSignal: IconDefinition;
export const faSignature: IconDefinition;
export const faSimCard: IconDefinition;
export const faSitemap: IconDefinition;
export const faSkating: IconDefinition;
export const faSkiing: IconDefinition;
export const faSkiingNordic: IconDefinition;
export const faSkull: IconDefinition;
export const faSkullCrossbones: IconDefinition;
export const faSlash: IconDefinition;
export const faSleigh: IconDefinition;
export const faSlidersH: IconDefinition;
export const faSmile: IconDefinition;
export const faSmileBeam: IconDefinition;
export const faSmileWink: IconDefinition;
export const faSmog: IconDefinition;
export const faSmoking: IconDefinition;
export const faSmokingBan: IconDefinition;
export const faSms: IconDefinition;
export const faSnowboarding: IconDefinition;
export const faSnowflake: IconDefinition;
export const faSnowman: IconDefinition;
export const faSnowplow: IconDefinition;
export const faSocks: IconDefinition;
export const faSolarPanel: IconDefinition;
export const faSort: IconDefinition;
export const faSortAlphaDown: IconDefinition;
export const faSortAlphaDownAlt: IconDefinition;
export const faSortAlphaUp: IconDefinition;
export const faSortAlphaUpAlt: IconDefinition;
export const faSortAmountDown: IconDefinition;
export const faSortAmountDownAlt: IconDefinition;
export const faSortAmountUp: IconDefinition;
export const faSortAmountUpAlt: IconDefinition;
export const faSortDown: IconDefinition;
export const faSortNumericDown: IconDefinition;
export const faSortNumericDownAlt: IconDefinition;
export const faSortNumericUp: IconDefinition;
export const faSortNumericUpAlt: IconDefinition;
export const faSortUp: IconDefinition;
export const faSpa: IconDefinition;
export const faSpaceShuttle: IconDefinition;
export const faSpellCheck: IconDefinition;
export const faSpider: IconDefinition;
export const faSpinner: IconDefinition;
export const faSplotch: IconDefinition;
export const faSprayCan: IconDefinition;
export const faSquare: IconDefinition;
export const faSquareFull: IconDefinition;
export const faSquareRootAlt: IconDefinition;
export const faStamp: IconDefinition;
export const faStar: IconDefinition;
export const faStarAndCrescent: IconDefinition;
export const faStarHalf: IconDefinition;
export const faStarHalfAlt: IconDefinition;
export const faStarOfDavid: IconDefinition;
export const faStarOfLife: IconDefinition;
export const faStepBackward: IconDefinition;
export const faStepForward: IconDefinition;
export const faStethoscope: IconDefinition;
export const faStickyNote: IconDefinition;
export const faStop: IconDefinition;
export const faStopCircle: IconDefinition;
export const faStopwatch: IconDefinition;
export const faStore: IconDefinition;
export const faStoreAlt: IconDefinition;
export const faStream: IconDefinition;
export const faStreetView: IconDefinition;
export const faStrikethrough: IconDefinition;
export const faStroopwafel: IconDefinition;
export const faSubscript: IconDefinition;
export const faSubway: IconDefinition;
export const faSuitcase: IconDefinition;
export const faSuitcaseRolling: IconDefinition;
export const faSun: IconDefinition;
export const faSuperscript: IconDefinition;
export const faSurprise: IconDefinition;
export const faSwatchbook: IconDefinition;
export const faSwimmer: IconDefinition;
export const faSwimmingPool: IconDefinition;
export const faSynagogue: IconDefinition;
export const faSync: IconDefinition;
export const faSyncAlt: IconDefinition;
export const faSyringe: IconDefinition;
export const faTable: IconDefinition;
export const faTableTennis: IconDefinition;
export const faTablet: IconDefinition;
export const faTabletAlt: IconDefinition;
export const faTablets: IconDefinition;
export const faTachometerAlt: IconDefinition;
export const faTag: IconDefinition;
export const faTags: IconDefinition;
export const faTape: IconDefinition;
export const faTasks: IconDefinition;
export const faTaxi: IconDefinition;
export const faTeeth: IconDefinition;
export const faTeethOpen: IconDefinition;
export const faTemperatureHigh: IconDefinition;
export const faTemperatureLow: IconDefinition;
export const faTenge: IconDefinition;
export const faTerminal: IconDefinition;
export const faTextHeight: IconDefinition;
export const faTextWidth: IconDefinition;
export const faTh: IconDefinition;
export const faThLarge: IconDefinition;
export const faThList: IconDefinition;
export const faTheaterMasks: IconDefinition;
export const faThermometer: IconDefinition;
export const faThermometerEmpty: IconDefinition;
export const faThermometerFull: IconDefinition;
export const faThermometerHalf: IconDefinition;
export const faThermometerQuarter: IconDefinition;
export const faThermometerThreeQuarters: IconDefinition;
export const faThumbsDown: IconDefinition;
export const faThumbsUp: IconDefinition;
export const faThumbtack: IconDefinition;
export const faTicketAlt: IconDefinition;
export const faTimes: IconDefinition;
export const faTimesCircle: IconDefinition;
export const faTint: IconDefinition;
export const faTintSlash: IconDefinition;
export const faTired: IconDefinition;
export const faToggleOff: IconDefinition;
export const faToggleOn: IconDefinition;
export const faToilet: IconDefinition;
export const faToiletPaper: IconDefinition;
export const faToolbox: IconDefinition;
export const faTools: IconDefinition;
export const faTooth: IconDefinition;
export const faTorah: IconDefinition;
export const faToriiGate: IconDefinition;
export const faTractor: IconDefinition;
export const faTrademark: IconDefinition;
export const faTrafficLight: IconDefinition;
export const faTrailer: IconDefinition;
export const faTrain: IconDefinition;
export const faTram: IconDefinition;
export const faTransgender: IconDefinition;
export const faTransgenderAlt: IconDefinition;
export const faTrash: IconDefinition;
export const faTrashAlt: IconDefinition;
export const faTrashRestore: IconDefinition;
export const faTrashRestoreAlt: IconDefinition;
export const faTree: IconDefinition;
export const faTrophy: IconDefinition;
export const faTruck: IconDefinition;
export const faTruckLoading: IconDefinition;
export const faTruckMonster: IconDefinition;
export const faTruckMoving: IconDefinition;
export const faTruckPickup: IconDefinition;
export const faTshirt: IconDefinition;
export const faTty: IconDefinition;
export const faTv: IconDefinition;
export const faUmbrella: IconDefinition;
export const faUmbrellaBeach: IconDefinition;
export const faUnderline: IconDefinition;
export const faUndo: IconDefinition;
export const faUndoAlt: IconDefinition;
export const faUniversalAccess: IconDefinition;
export const faUniversity: IconDefinition;
export const faUnlink: IconDefinition;
export const faUnlock: IconDefinition;
export const faUnlockAlt: IconDefinition;
export const faUpload: IconDefinition;
export const faUser: IconDefinition;
export const faUserAlt: IconDefinition;
export const faUserAltSlash: IconDefinition;
export const faUserAstronaut: IconDefinition;
export const faUserCheck: IconDefinition;
export const faUserCircle: IconDefinition;
export const faUserClock: IconDefinition;
export const faUserCog: IconDefinition;
export const faUserEdit: IconDefinition;
export const faUserFriends: IconDefinition;
export const faUserGraduate: IconDefinition;
export const faUserInjured: IconDefinition;
export const faUserLock: IconDefinition;
export const faUserMd: IconDefinition;
export const faUserMinus: IconDefinition;
export const faUserNinja: IconDefinition;
export const faUserNurse: IconDefinition;
export const faUserPlus: IconDefinition;
export const faUserSecret: IconDefinition;
export const faUserShield: IconDefinition;
export const faUserSlash: IconDefinition;
export const faUserTag: IconDefinition;
export const faUserTie: IconDefinition;
export const faUserTimes: IconDefinition;
export const faUsers: IconDefinition;
export const faUsersCog: IconDefinition;
export const faUtensilSpoon: IconDefinition;
export const faUtensils: IconDefinition;
export const faVectorSquare: IconDefinition;
export const faVenus: IconDefinition;
export const faVenusDouble: IconDefinition;
export const faVenusMars: IconDefinition;
export const faVial: IconDefinition;
export const faVials: IconDefinition;
export const faVideo: IconDefinition;
export const faVideoSlash: IconDefinition;
export const faVihara: IconDefinition;
export const faVoicemail: IconDefinition;
export const faVolleyballBall: IconDefinition;
export const faVolumeDown: IconDefinition;
export const faVolumeMute: IconDefinition;
export const faVolumeOff: IconDefinition;
export const faVolumeUp: IconDefinition;
export const faVoteYea: IconDefinition;
export const faVrCardboard: IconDefinition;
export const faWalking: IconDefinition;
export const faWallet: IconDefinition;
export const faWarehouse: IconDefinition;
export const faWater: IconDefinition;
export const faWaveSquare: IconDefinition;
export const faWeight: IconDefinition;
export const faWeightHanging: IconDefinition;
export const faWheelchair: IconDefinition;
export const faWifi: IconDefinition;
export const faWind: IconDefinition;
export const faWindowClose: IconDefinition;
export const faWindowMaximize: IconDefinition;
export const faWindowMinimize: IconDefinition;
export const faWindowRestore: IconDefinition;
export const faWineBottle: IconDefinition;
export const faWineGlass: IconDefinition;
export const faWineGlassAlt: IconDefinition;
export const faWonSign: IconDefinition;
export const faWrench: IconDefinition;
export const faXRay: IconDefinition;
export const faYenSign: IconDefinition;
export const faYinYang: IconDefinition;
export const fas: IconPack;